import{S as _,i as g,s as c,M as b,e as m,a as d,t as f,b as v,O as h,P as y,Q as w,x as B,y as S,j}from"./index.65fb5956.js";function k(l){let s,n,t;const i=l[5].default,a=b(i,l,l[4],null);return{c(){s=m("div"),a&&a.c(),d(s,"class",n="gr-box overflow-hidden "+l[3][l[0]]+" "+l[3][l[1]]),f(s,"gr-panel",l[2])},m(e,o){v(e,s,o),a&&a.m(s,null),t=!0},p(e,[o]){a&&a.p&&(!t||o&16)&&h(a,i,e,e[4],t?w(i,e[4],o,null):y(e[4]),null),(!t||o&3&&n!==(n="gr-box overflow-hidden "+e[3][e[0]]+" "+e[3][e[1]]))&&d(s,"class",n),o&7&&f(s,"gr-panel",e[2])},i(e){t||(B(a,e),t=!0)},o(e){S(a,e),t=!1},d(e){e&&j(s),a&&a.d(e)}}}function q(l,s,n){let{$$slots:t={},$$scope:i}=s,{variant:a="solid"}=s,{color:e="grey"}=s,{padding:o=!0}=s;const u={dashed:"border-dashed border-2",solid:"border-solid border",grey:"border-gray-200",green:"border-green-400"};return l.$$set=r=>{"variant"in r&&n(0,a=r.variant),"color"in r&&n(1,e=r.color),"padding"in r&&n(2,o=r.padding),"$$scope"in r&&n(4,i=r.$$scope)},[a,e,o,u,i,t]}class M extends _{constructor(s){super(),g(this,s,q,k,c,{variant:0,color:1,padding:2})}}export{M as B};
