import{S as i,i as r,s as u,M as f,e as _,a as c,b as p,O as m,P as $,Q as d,x as b,y as g,j as h}from"./index.65fb5956.js";function k(l){let e,a;const n=l[1].default,s=f(n,l,l[0],null);return{c(){e=_("span"),s&&s.c(),c(e,"class","text-gray-600 text-sm mb-2 block")},m(t,o){p(t,e,o),s&&s.m(e,null),a=!0},p(t,[o]){s&&s.p&&(!a||o&1)&&m(s,n,t,t[0],a?d(n,t[0],o,null):$(t[0]),null)},i(t){a||(b(s,t),a=!0)},o(t){g(s,t),a=!1},d(t){t&&h(e),s&&s.d(t)}}}function y(l,e,a){let{$$slots:n={},$$scope:s}=e;return l.$$set=t=>{"$$scope"in t&&a(0,s=t.$$scope)},[s,n]}class S extends i{constructor(e){super(),r(this,e,y,k,u,{})}}export{S as B};
