import{S as q,i as B,s as A,e as g,a as h,b as _,A as j,y as k,B as O,x as v,j as d,f as a,g as m,h as y,q as p,k as I,u as S,m as C,v as w,z as N,o as K,c as M,C as P}from"./index.65fb5956.js";function z(f,e,l){const n=f.slice();return n[5]=e[l],n[7]=l,n}function D(f,e,l){const n=f.slice();return n[5]=e[l],n[7]=l,n}function Q(f){let e,l;return{c(){e=g("div"),l=a(f[1]),h(e,"class","json-item inline"),h(e,"item-type","other")},m(n,o){_(n,e,o),m(e,l)},p(n,o){o&2&&y(l,n[1])},i:p,o:p,d(n){n&&d(e)}}}function R(f){let e,l;return{c(){e=g("div"),l=a(f[1]),h(e,"class","json-item inline text-blue-500"),h(e,"item-type","number")},m(n,o){_(n,e,o),m(e,l)},p(n,o){o&2&&y(l,n[1])},i:p,o:p,d(n){n&&d(e)}}}function T(f){let e,l=f[1].toLocaleString()+"",n;return{c(){e=g("div"),n=a(l),h(e,"class","json-item inline text-red-500"),h(e,"item-type","boolean")},m(o,c){_(o,e,c),m(e,n)},p(o,c){c&2&&l!==(l=o[1].toLocaleString()+"")&&y(n,l)},i:p,o:p,d(o){o&&d(e)}}}function U(f){let e,l,n,o;return{c(){e=g("div"),l=a('"'),n=a(f[1]),o=a('"'),h(e,"class","json-item inline text-green-500"),h(e,"item-type","string")},m(c,i){_(c,e,i),m(e,l),m(e,n),m(e,o)},p(c,i){i&2&&y(n,c[1])},i:p,o:p,d(c){c&&d(e)}}}function V(f){let e;return{c(){e=g("div"),e.textContent="null",h(e,"class","json-item inline text-gray-500 dark:text-gray-400"),h(e,"item-type","null")},m(l,n){_(l,e,n)},p,i:p,o:p,d(l){l&&d(e)}}}function W(f){let e,l,n,o;const c=[Z,Y],i=[];function u(t,r){return t[0]?0:1}return e=u(f),l=i[e]=c[e](f),{c(){l.c(),n=I()},m(t,r){i[e].m(t,r),_(t,n,r),o=!0},p(t,r){let s=e;e=u(t),e===s?i[e].p(t,r):(j(),k(i[s],1,1,()=>{i[s]=null}),O(),l=i[e],l?l.p(t,r):(l=i[e]=c[e](t),l.c()),v(l,1),l.m(n.parentNode,n))},i(t){o||(v(l),o=!0)},o(t){k(l),o=!1},d(t){i[e].d(t),t&&d(n)}}}function X(f){let e,l,n,o;const c=[x,$],i=[];function u(t,r){return t[0]?0:1}return e=u(f),l=i[e]=c[e](f),{c(){l.c(),n=I()},m(t,r){i[e].m(t,r),_(t,n,r),o=!0},p(t,r){let s=e;e=u(t),e===s?i[e].p(t,r):(j(),k(i[s],1,1,()=>{i[s]=null}),O(),l=i[e],l?l.p(t,r):(l=i[e]=c[e](t),l.c()),v(l,1),l.m(n.parentNode,n))},i(t){o||(v(l),o=!0)},o(t){k(l),o=!1},d(t){i[e].d(t),t&&d(n)}}}function Y(f){let e,l,n,o,c=Object.entries(f[1]),i=[];for(let t=0;t<c.length;t+=1)i[t]=F(z(f,c,t));const u=t=>k(i[t],1,1,()=>{i[t]=null});return{c(){e=a(`{
			`),l=g("div");for(let t=0;t<i.length;t+=1)i[t].c();n=a(`
			}`),h(l,"class","json-children pl-4")},m(t,r){_(t,e,r),_(t,l,r);for(let s=0;s<i.length;s+=1)i[s].m(l,null);_(t,n,r),o=!0},p(t,r){if(r&6){c=Object.entries(t[1]);let s;for(s=0;s<c.length;s+=1){const b=z(t,c,s);i[s]?(i[s].p(b,r),v(i[s],1)):(i[s]=F(b),i[s].c(),v(i[s],1),i[s].m(l,null))}for(j(),s=c.length;s<i.length;s+=1)u(s);O()}},i(t){if(!o){for(let r=0;r<c.length;r+=1)v(i[r]);o=!0}},o(t){i=i.filter(Boolean);for(let r=0;r<i.length;r+=1)k(i[r]);o=!1},d(t){t&&d(e),t&&d(l),K(i,t),t&&d(n)}}}function Z(f){let e,l,n=Object.keys(f[1]).length+"",o,c,i,u;return{c(){e=g("button"),l=a("{+"),o=a(n),c=a(" items}")},m(t,r){_(t,e,r),m(e,l),m(e,o),m(e,c),i||(u=M(e,"click",f[4]),i=!0)},p(t,r){r&2&&n!==(n=Object.keys(t[1]).length+"")&&y(o,n)},i:p,o:p,d(t){t&&d(e),i=!1,u()}}}function E(f){let e;return{c(){e=a(",")},m(l,n){_(l,e,n)},d(l){l&&d(e)}}}function F(f){let e,l=f[5][0]+"",n,o,c,i=f[7]!==Object.keys(f[1]).length-1,u,t;c=new L({props:{value:f[5][1],depth:f[2]+1,key:f[7]}});let r=i&&E();return{c(){e=g("div"),n=a(l),o=a(": "),S(c.$$.fragment),r&&r.c(),u=C(),h(e,"class","json-item")},m(s,b){_(s,e,b),m(e,n),m(e,o),w(c,e,null),r&&r.m(e,null),m(e,u),t=!0},p(s,b){(!t||b&2)&&l!==(l=s[5][0]+"")&&y(n,l);const J={};b&2&&(J.value=s[5][1]),b&4&&(J.depth=s[2]+1),c.$set(J),b&2&&(i=s[7]!==Object.keys(s[1]).length-1),i?r||(r=E(),r.c(),r.m(e,u)):r&&(r.d(1),r=null)},i(s){t||(v(c.$$.fragment,s),t=!0)},o(s){k(c.$$.fragment,s),t=!1},d(s){s&&d(e),N(c),r&&r.d()}}}function $(f){let e,l,n,o,c=f[1],i=[];for(let t=0;t<c.length;t+=1)i[t]=H(D(f,c,t));const u=t=>k(i[t],1,1,()=>{i[t]=null});return{c(){e=a(`[
			`),l=g("div");for(let t=0;t<i.length;t+=1)i[t].c();n=a(`
			]`),h(l,"class","json-children pl-4")},m(t,r){_(t,e,r),_(t,l,r);for(let s=0;s<i.length;s+=1)i[s].m(l,null);_(t,n,r),o=!0},p(t,r){if(r&6){c=t[1];let s;for(s=0;s<c.length;s+=1){const b=D(t,c,s);i[s]?(i[s].p(b,r),v(i[s],1)):(i[s]=H(b),i[s].c(),v(i[s],1),i[s].m(l,null))}for(j(),s=c.length;s<i.length;s+=1)u(s);O()}},i(t){if(!o){for(let r=0;r<c.length;r+=1)v(i[r]);o=!0}},o(t){i=i.filter(Boolean);for(let r=0;r<i.length;r+=1)k(i[r]);o=!1},d(t){t&&d(e),t&&d(l),K(i,t),t&&d(n)}}}function x(f){let e,l,n=f[1].length+"",o,c,i,u;return{c(){e=g("button"),l=a("[+"),o=a(n),c=a(" children]")},m(t,r){_(t,e,r),m(e,l),m(e,o),m(e,c),i||(u=M(e,"click",f[3]),i=!0)},p(t,r){r&2&&n!==(n=t[1].length+"")&&y(o,n)},i:p,o:p,d(t){t&&d(e),i=!1,u()}}}function G(f){let e;return{c(){e=a(",")},m(l,n){_(l,e,n)},d(l){l&&d(e)}}}function H(f){let e,l,n,o,c,i,u;o=new L({props:{value:f[5],depth:f[2]+1}});let t=f[7]!==f[1].length-1&&G();return{c(){e=g("div"),l=a(f[7]),n=a(": "),S(o.$$.fragment),c=C(),t&&t.c(),i=C(),h(e,"class","json-item")},m(r,s){_(r,e,s),m(e,l),m(e,n),w(o,e,null),m(e,c),t&&t.m(e,null),m(e,i),u=!0},p(r,s){const b={};s&2&&(b.value=r[5]),s&4&&(b.depth=r[2]+1),o.$set(b),r[7]!==r[1].length-1?t||(t=G(),t.c(),t.m(e,i)):t&&(t.d(1),t=null)},i(r){u||(v(o.$$.fragment,r),u=!0)},o(r){k(o.$$.fragment,r),u=!1},d(r){r&&d(e),N(o),t&&t.d()}}}function ee(f){let e,l,n,o;const c=[X,W,V,U,T,R,Q],i=[];function u(t,r){return t[1]instanceof Array?0:t[1]instanceof Object?1:t[1]===null?2:typeof t[1]=="string"?3:typeof t[1]=="boolean"?4:typeof t[1]=="number"?5:6}return l=u(f),n=i[l]=c[l](f),{c(){e=g("div"),n.c(),h(e,"class","json-node inline")},m(t,r){_(t,e,r),i[l].m(e,null),o=!0},p(t,[r]){let s=l;l=u(t),l===s?i[l].p(t,r):(j(),k(i[s],1,1,()=>{i[s]=null}),O(),n=i[l],n?n.p(t,r):(n=i[l]=c[l](t),n.c()),v(n,1),n.m(e,null))},i(t){o||(v(n),o=!0)},o(t){k(n),o=!1},d(t){t&&d(e),i[l].d()}}}function te(f,e,l){let{value:n}=e,{depth:o}=e,{collapsed:c=o>4}=e;const i=()=>{l(0,c=!1)},u=()=>{l(0,c=!1)};return f.$$set=t=>{"value"in t&&l(1,n=t.value),"depth"in t&&l(2,o=t.depth),"collapsed"in t&&l(0,c=t.collapsed)},[c,n,o,i,u]}class L extends q{constructor(e){super(),B(this,e,te,ee,A,{value:1,depth:2,collapsed:0})}}function le(f){let e,l,n;return l=new L({props:{value:f[0],depth:0}}),{c(){e=g("div"),S(l.$$.fragment),h(e,"class","output-json font-mono leading-relaxed w-full svelte-7lqb9h")},m(o,c){_(o,e,c),w(l,e,null),n=!0},p(o,[c]){const i={};c&1&&(i.value=o[0]),l.$set(i)},i(o){n||(v(l.$$.fragment,o),n=!0)},o(o){k(l.$$.fragment,o),n=!1},d(o){o&&d(e),N(l)}}}function ne(f,e,l){let{value:n={}}=e,{style:o=""}=e;return f.$$set=c=>{"value"in c&&l(0,n=c.value),"style"in c&&l(1,o=c.style)},[n,o]}class ie extends q{constructor(e){super(),B(this,e,ne,le,A,{value:0,style:1})}}function oe(f){let e,l;return e=new ie({props:{style:f[1],value:f[0]}}),{c(){S(e.$$.fragment)},m(n,o){w(e,n,o),l=!0},p(n,[o]){const c={};o&2&&(c.style=n[1]),o&1&&(c.value=n[0]),e.$set(c)},i(n){l||(v(e.$$.fragment,n),l=!0)},o(n){k(e.$$.fragment,n),l=!1},d(n){N(e,n)}}}function re(f,e,l){let{value:n={}}=e,{default_value:o}=e,{style:c=""}=e;const i=P();return o&&(n=o),f.$$set=u=>{"value"in u&&l(0,n=u.value),"default_value"in u&&l(2,o=u.default_value),"style"in u&&l(1,c=u.style)},f.$$.update=()=>{f.$$.dirty&1&&i("change")},[n,c,o]}class ce extends q{constructor(e){super(),B(this,e,re,oe,A,{value:0,default_value:2,style:1})}}var fe=ce;const ue=["static"];export{fe as Component,ue as modes};
