import{S as _,i as h,s as m,u as g,v as k,x as v,y,z as C,C as w,e as r,m as B,f as E,a as d,b as S,g as b,c as j,h as q,j as z,E as D,K as G,H,G as K}from"./index.65fb5956.js";import{B as x}from"./Block.3fbf618d.js";function A(s){let e,a,t,c,i,l,u;return{c(){e=r("label"),a=r("input"),t=B(),c=r("span"),i=E(s[2]),a.disabled=s[1],d(a,"type","checkbox"),d(a,"name","test"),d(a,"class","gr-check-radio rounded checked:shadow-inner"),d(c,"class","ml-2"),d(e,"class","")},m(n,o){S(n,e,o),b(e,a),a.checked=s[0],b(e,t),b(e,c),b(c,i),l||(u=j(a,"change",s[4]),l=!0)},p(n,o){o&2&&(a.disabled=n[1]),o&1&&(a.checked=n[0]),o&4&&q(i,n[2])},d(n){n&&z(e),l=!1,u()}}}function F(s){let e,a;return e=new x({props:{$$slots:{default:[A]},$$scope:{ctx:s}}}),{c(){g(e.$$.fragment)},m(t,c){k(e,t,c),a=!0},p(t,[c]){const i={};c&135&&(i.$$scope={dirty:c,ctx:t}),e.$set(i)},i(t){a||(v(e.$$.fragment,t),a=!0)},o(t){y(e.$$.fragment,t),a=!1},d(t){C(e,t)}}}function I(s,e,a){let{value:t}=e,{disabled:c=!1}=e,{label:i}=e,{style:l=""}=e;w();function u(){t=this.checked,a(0,t)}return s.$$set=n=>{"value"in n&&a(0,t=n.value),"disabled"in n&&a(1,c=n.disabled),"label"in n&&a(2,i=n.label),"style"in n&&a(3,l=n.style)},[t,c,i,l,u]}class J extends _{constructor(e){super(),h(this,e,I,F,m,{value:0,disabled:1,label:2,style:3})}}function L(s){let e,a,t;function c(l){s[5](l)}let i={style:s[1],label:s[2],disabled:s[3]==="static"};return s[0]!==void 0&&(i.value=s[0]),e=new J({props:i}),D.push(()=>G(e,"value",c)),e.$on("change",s[6]),{c(){g(e.$$.fragment)},m(l,u){k(e,l,u),t=!0},p(l,[u]){const n={};u&2&&(n.style=l[1]),u&4&&(n.label=l[2]),u&8&&(n.disabled=l[3]==="static"),!a&&u&1&&(a=!0,n.value=l[0],H(()=>a=!1)),e.$set(n)},i(l){t||(v(e.$$.fragment,l),t=!0)},o(l){y(e.$$.fragment,l),t=!1},d(l){C(e,l)}}}function M(s,e,a){let{value:t=!1}=e,{default_value:c=!1}=e,{style:i=""}=e,{label:l}=e,{mode:u}=e;c&&(t=c);function n(f){t=f,a(0,t)}function o(f){K.call(this,s,f)}return s.$$set=f=>{"value"in f&&a(0,t=f.value),"default_value"in f&&a(4,c=f.default_value),"style"in f&&a(1,i=f.style),"label"in f&&a(2,l=f.label),"mode"in f&&a(3,u=f.mode)},[t,i,l,u,c,n,o]}class N extends _{constructor(e){super(),h(this,e,M,L,m,{value:0,default_value:4,style:1,label:2,mode:3})}}var Q=N;const R=["static","dynamic"];export{Q as Component,R as modes};
