import{S as D,i as G,s as H,u as w,v as B,x as S,y as C,z as j,C as T,e as g,m as E,f as K,a as b,b as v,g as h,_ as q,c as z,h as R,j as k,r as A,aa as F,E as I,K as J,H as L,G as M}from"./index.65fb5956.js";import{B as N}from"./Block.3fbf618d.js";import{B as O}from"./BlockTitle.87c2b95a.js";function P(n){let l;return{c(){l=K(n[5])},m(t,a){v(t,l,a)},p(t,a){a&32&&R(l,t[5])},d(t){t&&k(l)}}}function Q(n){let l,t,a,m,_,i,s,f,u,c,o,r;return m=new O({props:{$$slots:{default:[P]},$$scope:{ctx:n}}}),{c(){l=g("div"),t=g("div"),a=g("label"),w(m.$$.fragment),_=E(),i=g("div"),s=K(n[0]),f=E(),u=g("input"),b(a,"for",n[6]),b(i,"class","font-medium"),b(t,"class","flex justify-between"),b(l,"class","w-full flex flex-col"),b(u,"type","range"),b(u,"id",n[6]),b(u,"name","cowbell"),b(u,"class","w-full"),b(u,"min",n[1]),b(u,"max",n[2]),b(u,"step",n[3]),u.disabled=n[4]},m(e,d){v(e,l,d),h(l,t),h(t,a),B(m,a,null),h(t,_),h(t,i),h(i,s),v(e,f,d),v(e,u,d),q(u,n[0]),c=!0,o||(r=[z(u,"change",n[8]),z(u,"input",n[8])],o=!0)},p(e,d){const y={};d&1056&&(y.$$scope={dirty:d,ctx:e}),m.$set(y),(!c||d&1)&&R(s,e[0]),(!c||d&2)&&b(u,"min",e[1]),(!c||d&4)&&b(u,"max",e[2]),(!c||d&8)&&b(u,"step",e[3]),(!c||d&16)&&(u.disabled=e[4]),d&1&&q(u,e[0])},i(e){c||(S(m.$$.fragment,e),c=!0)},o(e){C(m.$$.fragment,e),c=!1},d(e){e&&k(l),j(m),e&&k(f),e&&k(u),o=!1,A(r)}}}function U(n){let l,t;return l=new N({props:{$$slots:{default:[Q]},$$scope:{ctx:n}}}),{c(){w(l.$$.fragment)},m(a,m){B(l,a,m),t=!0},p(a,[m]){const _={};m&1087&&(_.$$scope={dirty:m,ctx:a}),l.$set(_)},i(a){t||(S(l.$$.fragment,a),t=!0)},o(a){C(l.$$.fragment,a),t=!1},d(a){j(l,a)}}}let V=0;function W(n,l,t){let{value:a=0}=l,{style:m=""}=l,{minimum:_=0}=l,{maximum:i=100}=l,{step:s=1}=l,{disabled:f=!1}=l,{label:u}=l;const c=`range_id_${V++}`,o=T();function r(){a=F(this.value),t(0,a)}return n.$$set=e=>{"value"in e&&t(0,a=e.value),"style"in e&&t(7,m=e.style),"minimum"in e&&t(1,_=e.minimum),"maximum"in e&&t(2,i=e.maximum),"step"in e&&t(3,s=e.step),"disabled"in e&&t(4,f=e.disabled),"label"in e&&t(5,u=e.label)},n.$$.update=()=>{n.$$.dirty&1&&o("change",a)},[a,_,i,s,f,u,c,m,r]}class X extends D{constructor(l){super(),G(this,l,W,U,H,{value:0,style:7,minimum:1,maximum:2,step:3,disabled:4,label:5})}}function Y(n){let l,t,a;function m(i){n[8](i)}let _={label:n[1],style:n[2],minimum:n[3],maximum:n[4],step:n[5],disabled:n[6]==="static"};return n[0]!==void 0&&(_.value=n[0]),l=new X({props:_}),I.push(()=>J(l,"value",m)),l.$on("change",n[9]),{c(){w(l.$$.fragment)},m(i,s){B(l,i,s),a=!0},p(i,[s]){const f={};s&2&&(f.label=i[1]),s&4&&(f.style=i[2]),s&8&&(f.minimum=i[3]),s&16&&(f.maximum=i[4]),s&32&&(f.step=i[5]),s&64&&(f.disabled=i[6]==="static"),!t&&s&1&&(t=!0,f.value=i[0],L(()=>t=!1)),l.$set(f)},i(i){a||(S(l.$$.fragment,i),a=!0)},o(i){C(l.$$.fragment,i),a=!1},d(i){j(l,i)}}}function Z(n,l,t){let{value:a=0}=l,{label:m}=l,{default_value:_}=l,{style:i=""}=l,{minimum:s}=l,{maximum:f}=l,{step:u}=l,{mode:c}=l;_&&(a=_);function o(e){a=e,t(0,a)}function r(e){M.call(this,n,e)}return n.$$set=e=>{"value"in e&&t(0,a=e.value),"label"in e&&t(1,m=e.label),"default_value"in e&&t(7,_=e.default_value),"style"in e&&t(2,i=e.style),"minimum"in e&&t(3,s=e.minimum),"maximum"in e&&t(4,f=e.maximum),"step"in e&&t(5,u=e.step),"mode"in e&&t(6,c=e.mode)},[a,m,i,s,f,u,c,_,o,r]}class x extends D{constructor(l){super(),G(this,l,Z,Y,H,{value:0,label:1,default_value:7,style:2,minimum:3,maximum:4,step:5,mode:6})}}var le=x;const te=["static","dynamic"];export{le as Component,te as modes};
