import{S as r,i as c,s as d,M as m,e as v,a as i,t as _,b as g,O as y,P as h,Q as C,x as b,y as S,j}from"./index.65fb5956.js";function q(n){let t,s;const f=n[4].default,l=m(f,n,n[3],null);return{c(){t=v("div"),l&&l.c(),i(t,"style",n[1]),i(t,"class","flex flex-1 flex-col gap-4 relative"),_(t,"hidden",!n[0])},m(e,a){g(e,t,a),l&&l.m(t,null),s=!0},p(e,[a]){l&&l.p&&(!s||a&8)&&y(l,f,e,e[3],s?C(f,e[3],a,null):h(e[3]),null),(!s||a&2)&&i(t,"style",e[1]),a&1&&_(t,"hidden",!e[0])},i(e){s||(b(l,e),s=!0)},o(e){S(l,e),s=!1},d(e){e&&j(t),l&&l.d(e)}}}function M(n,t,s){let{$$slots:f={},$$scope:l}=t,{value:e=!0}=t,{default_value:a}=t,{style:o=""}=t;return a&&(e=a),n.$$set=u=>{"value"in u&&s(0,e=u.value),"default_value"in u&&s(2,a=u.default_value),"style"in u&&s(1,o=u.style),"$$scope"in u&&s(3,l=u.$$scope)},[e,o,a,l,f]}class O extends r{constructor(t){super(),c(this,t,M,q,d,{value:0,default_value:2,style:1})}}var Q=O;const k=["static"];export{Q as Component,k as modes};
