import{S as _,i as c,s as m,M as h,e as k,a as f,b as v,c as B,O as q,P as C,Q as S,x as d,y,j as b,G as g,u as j,v as w,z,L as G,X as L,f as M,h as O}from"./index.65fb5956.js";function P(l){let t,a,e,s,o;const r=l[3].default,i=h(r,l,l[2],null);return{c(){t=k("button"),i&&i.c(),f(t,"style",l[1]),f(t,"class",a=l[0]+" flex-1 px-4 py-2 bg-gray-100 rounded transition svelte-99qade")},m(n,u){v(n,t,u),i&&i.m(t,null),e=!0,s||(o=B(t,"click",l[4]),s=!0)},p(n,[u]){i&&i.p&&(!e||u&4)&&q(i,r,n,n[2],e?S(r,n[2],u,null):C(n[2]),null),(!e||u&2)&&f(t,"style",n[1]),(!e||u&1&&a!==(a=n[0]+" flex-1 px-4 py-2 bg-gray-100 rounded transition svelte-99qade"))&&f(t,"class",a)},i(n){e||(d(i,n),e=!0)},o(n){y(i,n),e=!1},d(n){n&&b(t),i&&i.d(n),s=!1,o()}}}function Q(l,t,a){let{$$slots:e={},$$scope:s}=t,{variant:o="primary"}=t,{style:r=""}=t;function i(n){g.call(this,l,n)}return l.$$set=n=>{"variant"in n&&a(0,o=n.variant),"style"in n&&a(1,r=n.style),"$$scope"in n&&a(2,s=n.$$scope)},[o,r,s,e,i]}class X extends _{constructor(t){super(),c(this,t,Q,P,m,{variant:0,style:1})}}function A(l){let t=l[3](l[0])+"",a;return{c(){a=M(t)},m(e,s){v(e,a,s)},p(e,s){s&9&&t!==(t=e[3](e[0])+"")&&O(a,t)},d(e){e&&b(a)}}}function D(l){let t,a;return t=new X({props:{variant:l[2],style:l[1],$$slots:{default:[A]},$$scope:{ctx:l}}}),t.$on("click",l[5]),{c(){j(t.$$.fragment)},m(e,s){w(t,e,s),a=!0},p(e,[s]){const o={};s&4&&(o.variant=e[2]),s&2&&(o.style=e[1]),s&73&&(o.$$scope={dirty:s,ctx:e}),t.$set(o)},i(e){a||(d(t.$$.fragment,e),a=!0)},o(e){y(t.$$.fragment,e),a=!1},d(e){z(t,e)}}}function E(l,t,a){let e;G(l,L,u=>a(3,e=u));let{value:s}=t,{default_value:o}=t,{style:r=""}=t,{variant:i="primary"}=t;o&&(s=o);function n(u){g.call(this,l,u)}return l.$$set=u=>{"value"in u&&a(0,s=u.value),"default_value"in u&&a(4,o=u.default_value),"style"in u&&a(1,r=u.style),"variant"in u&&a(2,i=u.variant)},[s,r,i,e,o,n]}class F extends _{constructor(t){super(),c(this,t,E,D,m,{value:0,default_value:4,style:1,variant:2})}}var I=F;const J=["static"];export{I as Component,J as modes};
