.output-label[theme=default].svelte-1be4tjy .label.svelte-1be4tjy{height:1.75rem;font-size:1rem;line-height:1.5rem}.output-label[theme=default].svelte-1be4tjy .confidence.svelte-1be4tjy{box-sizing:border-box;height:1.75rem;border-radius:.25rem;border-bottom-width:2px;--tw-border-opacity:1;border-color:rgb(209 213 219 / var(--tw-border-opacity));--tw-bg-opacity:1;background-color:rgb(229 231 235 / var(--tw-bg-opacity));font-family:monospace;font-size:.875rem;line-height:1.25rem;font-weight:600}.output-label[theme=default].svelte-1be4tjy .dark .confidence.svelte-1be4tjy{--tw-border-opacity:1;border-color:rgb(75 85 99 / var(--tw-border-opacity));--tw-bg-opacity:1;background-color:rgb(107 114 128 / var(--tw-bg-opacity))}.output-label[theme=default].svelte-1be4tjy .confidence.svelte-1be4tjy:first-child{--tw-border-opacity:1;border-color:rgb(185 28 28 / var(--tw-border-opacity));--tw-bg-opacity:1;background-color:rgb(245 158 11 / var(--tw-bg-opacity));--tw-text-opacity:1;color:rgb(255 255 255 / var(--tw-text-opacity))}.output-label[theme=default].svelte-1be4tjy .dark .confidence.svelte-1be4tjy:first-child{--tw-bg-opacity:1;background-color:rgb(220 38 38 / var(--tw-bg-opacity))}
