import{S as f,i,s as _,u as m,v as p,x as r,y as u,z as $,M as d,O as g,P as h,Q as y,G as C}from"./index.65fb5956.js";import{C as b}from"./Carousel.9a82e69e.js";function v(n){let s;const o=n[1].default,e=d(o,n,n[3],null);return{c(){e&&e.c()},m(t,a){e&&e.m(t,a),s=!0},p(t,a){e&&e.p&&(!s||a&8)&&g(e,o,t,t[3],s?y(o,t[3],a,null):h(t[3]),null)},i(t){s||(r(e,t),s=!0)},o(t){u(e,t),s=!1},d(t){e&&e.d(t)}}}function S(n){let s,o;return s=new b({props:{style:n[0],$$slots:{default:[v]},$$scope:{ctx:n}}}),s.$on("change",n[2]),{c(){m(s.$$.fragment)},m(e,t){p(s,e,t),o=!0},p(e,[t]){const a={};t&1&&(a.style=e[0]),t&8&&(a.$$scope={dirty:t,ctx:e}),s.$set(a)},i(e){o||(r(s.$$.fragment,e),o=!0)},o(e){u(s.$$.fragment,e),o=!1},d(e){$(s,e)}}}function q(n,s,o){let{$$slots:e={},$$scope:t}=s,{style:a=""}=s;function c(l){C.call(this,n,l)}return n.$$set=l=>{"style"in l&&o(0,a=l.style),"$$scope"in l&&o(3,t=l.$$scope)},[a,e,c,t]}class w extends f{constructor(s){super(),i(this,s,q,S,_,{style:0})}}var M=w;const O=["static"];export{M as Component,O as modes};
