.cover_container.svelte-91poyq{position:absolute;top:0px;left:0px;z-index:10;display:flex;height:100%;width:100%;flex-direction:column;align-items:center;justify-content:center;background-color:rgb(243 244 246 / var(--tw-bg-opacity));--tw-bg-opacity:.25}@keyframes svelte-91poyq-blink{0%{opacity:100%}50%{opacity:60%}to{opacity:100%}}.blink.svelte-91poyq{animation:svelte-91poyq-blink 2s infinite}@keyframes svelte-91poyq-bounce{0%{left:0%}50%{left:75%}to{left:0%}}.bounce.svelte-91poyq{animation:svelte-91poyq-bounce 2s infinite linear}
